# Generated by Django 2.0.4 on 2018-05-03 09:12

import datetime

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0009_auto_20180430_1225"),
    ]

    operations = [
        migrations.AlterField(
            model_name="law",
            name="book",
            field=models.ForeignKey(
                help_text="The book this law belongs to",
                on_delete=django.db.models.deletion.CASCADE,
                to="laws.LawBook",
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="content",
            field=models.TextField(
                blank=True, help_text="Law content with HTML tags and reference markers"
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="created_date",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Date of creation of this database entry"
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="doknr",
            field=models.CharField(
                blank=True,
                help_text="Document number as in XML source",
                max_length=200,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="footnotes",
            field=models.TextField(
                blank=True, help_text="Footnotes as JSON array", null=True
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="order",
            field=models.PositiveSmallIntegerField(
                default=0, help_text="Order within law book"
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="previous",
            field=models.ForeignKey(
                help_text="Points to previous law based on order value",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="previous_law",
                to="laws.Law",
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="slug",
            field=models.SlugField(help_text="Slug based on section", max_length=200),
        ),
        migrations.AlterField(
            model_name="law",
            name="text",
            field=models.TextField(blank=True, help_text="Plain text for searching"),
        ),
        migrations.AlterField(
            model_name="law",
            name="title",
            field=models.CharField(
                default="", help_text="Verbose title of law", max_length=200
            ),
        ),
        migrations.AlterField(
            model_name="law",
            name="updated_date",
            field=models.DateTimeField(
                auto_now=True, help_text="Last change of database entry"
            ),
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="code",
            field=models.CharField(
                default="unknown",
                help_text="Book code (usually short title)",
                max_length=100,
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="latest",
            field=models.BooleanField(
                default=True,
                help_text="Is true if this is the latest revision of this book",
            ),
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="order",
            field=models.PositiveSmallIntegerField(
                db_index=True,
                default=0,
                help_text="Indicates importance of this law book (used to order books in front end)",
            ),
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="revision_date",
            field=models.DateField(
                default=datetime.date(1990, 1, 1), help_text="Date of revision"
            ),
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="slug",
            field=models.SlugField(help_text="Slugified book code", max_length=200),
        ),
        migrations.AlterField(
            model_name="lawbook",
            name="title",
            field=models.CharField(
                default="Untitled book",
                help_text="Full title of the book",
                max_length=250,
            ),
        ),
        migrations.AlterUniqueTogether(
            name="lawbook",
            unique_together={("slug", "revision_date")},
        ),
    ]
