# Generated by Django 2.1.2 on 2018-10-30 12:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("topics", "0001_initial"),
        ("laws", "0015_remove_law_text"),
    ]

    operations = [
        migrations.AddField(
            model_name="lawbook",
            name="topics",
            field=models.ManyToManyField(
                help_text="Topics that are covered by this content", to="topics.Topic"
            ),
        ),
    ]
