# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2018-02-09 09:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0002_auto_20171221_1055"),
    ]

    operations = [
        migrations.AlterField(
            model_name="case",
            name="court_chamber",
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name="case",
            name="court_raw",
            field=models.CharField(default="{}", max_length=255),
        ),
        migrations.AlterField(
            model_name="case",
            name="ecli",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name="case",
            name="pdf_url",
            field=models.URLField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name="case",
            name="raw",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="case",
            name="source_url",
            field=models.URLField(max_length=255),
        ),
        migrations.AlterField(
            model_name="case",
            name="title",
            field=models.CharField(blank=True, default="", max_length=255),
        ),
    ]
