# Generated by Django 2.1.2 on 2018-10-24 15:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0012_auto_20180921_1104"),
    ]

    operations = [
        migrations.AlterField(
            model_name="lawbook",
            name="latest",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text="Is true if this is the latest revision of this book",
            ),
        ),
    ]
