# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2018-01-03 13:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0006_auto_20180103_1158"),
    ]

    operations = [
        migrations.AddField(
            model_name="lawbook",
            name="latest",
            field=models.BooleanField(default=True),
        ),
    ]
