# Generated by Django 5.1.15 on 2026-02-25 11:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("accounts", "0003_create_default_permissions"),
    ]

    operations = [
        migrations.AddField(
            model_name="apitoken",
            name="rate_limit",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Custom rate limit in requests per hour for this token. Leave blank to use the default rate.",
                null=True,
                verbose_name="Rate Limit",
            ),
        ),
    ]
