# Generated by Django 5.1.15 on 2026-01-29 16:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("accounts", "0003_create_default_permissions"),
        ("laws", "0020_add_created_by_token"),
        ("topics", "0003_alter_topic_id"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="law",
            index=models.Index(fields=["previous"], name="laws_law_previous_idx"),
        ),
        migrations.AddIndex(
            model_name="law",
            index=models.Index(
                fields=["book", "order"], name="laws_law_book_order_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="law",
            index=models.Index(fields=["section"], name="laws_law_section_idx"),
        ),
        migrations.AddIndex(
            model_name="lawbook",
            index=models.Index(
                fields=["code", "latest"], name="laws_lawbook_code_latest_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="relatedlaw",
            index=models.Index(
                fields=["seed_content", "-score"], name="laws_rellaw_seed_score_idx"
            ),
        ),
    ]
