# Generated by Django 5.1.15 on 2026-01-26 18:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("annotations", "0004_default_color"),
    ]

    operations = [
        migrations.AlterField(
            model_name="annotationlabel",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="caseannotation",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="casemarker",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
