# Generated by Django 2.0.4 on 2018-04-30 12:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0008_auto_20180106_1123"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="law",
            unique_together={("book", "slug")},
        ),
    ]
