# Generated by Django 2.1.2 on 2018-10-30 12:09

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Topic",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "title",
                    models.CharField(
                        help_text="Verbose title of topic", max_length=200, unique=True
                    ),
                ),
                (
                    "slug",
                    models.SlugField(
                        help_text="Slug based on title", max_length=200, unique=True
                    ),
                ),
                (
                    "created_date",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Date of creation of this database entry",
                    ),
                ),
                (
                    "updated_date",
                    models.DateTimeField(
                        auto_now=True, help_text="Last change of database entry"
                    ),
                ),
            ],
        ),
    ]
