# Generated by Django 2.0.4 on 2018-04-25 09:41

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="SearchQuery",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "query",
                    models.CharField(
                        db_index=True,
                        help_text="Query as entered by user but all lower case",
                        max_length=200,
                        unique=True,
                    ),
                ),
                (
                    "counter",
                    models.IntegerField(
                        default=1, help_text="Count of query executions"
                    ),
                ),
                (
                    "created_date",
                    models.DateTimeField(
                        auto_now_add=True, help_text="First query execution"
                    ),
                ),
                (
                    "updated_date",
                    models.DateTimeField(
                        auto_now=True, help_text="Last query execution"
                    ),
                ),
            ],
        ),
    ]
