# Generated by Django 5.1.15 on 2026-02-12 17:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0022_lawbook_created_date_lawbook_updated_date"),
    ]

    operations = [
        migrations.AddField(
            model_name="law",
            name="review_status",
            field=models.CharField(
                choices=[
                    ("pending", "Pending"),
                    ("accepted", "Accepted"),
                    ("rejected", "Rejected"),
                ],
                db_index=True,
                default="accepted",
                help_text="Review status for API-submitted laws",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="lawbook",
            name="review_status",
            field=models.CharField(
                choices=[
                    ("pending", "Pending"),
                    ("accepted", "Accepted"),
                    ("rejected", "Rejected"),
                ],
                db_index=True,
                default="accepted",
                help_text="Review status for API-submitted law books",
                max_length=10,
            ),
        ),
    ]
