# Generated by Django 2.1.2 on 2018-11-10 23:33

from django.db import migrations


class Migration(migrations.Migration):
    ####################
    # NLP apps has been migrated to another repo
    ####################

    dependencies = [
        ("cases", "0013_auto_20181105_1442"),
    ]

    operations = []
