# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-21 13:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("references", "0003_auto_20171221_1324"),
    ]

    operations = [
        migrations.AddField(
            model_name="casereference",
            name="to_hash",
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name="lawreference",
            name="to_hash",
            field=models.CharField(max_length=100, null=True),
        ),
    ]
