# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-06 21:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("courts", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="court",
            name="description",
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name="court",
            name="image",
            field=models.ImageField(default=None, upload_to="courts"),
            preserve_default=False,
        ),
    ]
