# Generated by Django 5.1.15 on 2026-02-12 10:46

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("accounts", "0003_create_default_permissions"),
        ("courts", "0018_alter_city_id_alter_country_id_alter_court_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="court",
            name="created_by_token",
            field=models.ForeignKey(
                blank=True,
                help_text="API token used to create this court",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="created_courts",
                to="accounts.apitoken",
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="created_date",
            field=models.DateTimeField(
                db_index=True, default=django.utils.timezone.now
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="review_status",
            field=models.CharField(
                choices=[
                    ("pending", "Pending"),
                    ("accepted", "Accepted"),
                    ("rejected", "Rejected"),
                ],
                db_index=True,
                default="accepted",
                help_text="Review status for API-submitted courts",
                max_length=10,
            ),
        ),
    ]
