# Generated by Django 2.1.2 on 2018-10-25 10:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0013_auto_20181024_1559"),
    ]

    operations = [
        migrations.AlterField(
            model_name="law",
            name="previous",
            field=models.ForeignKey(
                editable=False,
                help_text="Points to previous law based on order value",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="previous_law",
                to="laws.Law",
            ),
        ),
    ]
