# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-06 22:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("courts", "0003_auto_20171206_2143"),
    ]

    operations = [
        migrations.AddField(
            model_name="court",
            name="updated",
            field=models.DateTimeField(auto_now=True),
        ),
    ]
