# Generated by Django 5.1.15 on 2026-01-29 16:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0024_add_performance_indexes"),
        ("laws", "0021_add_performance_indexes"),
        ("references", "0010_alter_casereferencemarker_id_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="reference",
            index=models.Index(fields=["to_hash"], name="refs_ref_to_hash_idx"),
        ),
    ]
