# Generated by Django 2.0.4 on 2018-04-26 08:06

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("courts", "0011_court_email"),
        ("cases", "0007_auto_20180425_2039"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="case",
            unique_together={("court", "file_number")},
        ),
    ]
