# Generated by Django 5.1.15 on 2026-01-26 18:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0022_case_created_by_token"),
    ]

    operations = [
        migrations.RunSQL(
            sql="DROP TABLE IF EXISTS cases_case_nlp_entities;",
            reverse_sql=migrations.RunSQL.noop,
        ),
        migrations.AlterField(
            model_name="case",
            name="following_cases",
            field=models.ManyToManyField(
                blank=True,
                help_text="Cases from superior courts (higher judicial authority)",
                to="cases.case",
            ),
        ),
        migrations.AlterField(
            model_name="case",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="case",
            name="preceding_cases",
            field=models.ManyToManyField(
                blank=True,
                help_text="Cases from inferior courts (lower judicial authority)",
                to="cases.case",
            ),
        ),
        migrations.AlterField(
            model_name="relatedcase",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
