# Generated by Django 2.1.1 on 2018-09-17 14:55

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0010_auto_20180503_0912"),
    ]

    operations = [
        migrations.RenameField(
            model_name="law",
            old_name="enbez",
            new_name="section",
        ),
    ]
