# Generated by Django 2.1.2 on 2018-11-24 21:22

from django.db import migrations


class Migration(migrations.Migration):
    ####################
    # NLP apps has been migrated to another repo
    ####################

    dependencies = [
        ("cases", "0014_case_nlp_content"),
    ]

    operations = []
