# Generated by Django 2.1.2 on 2018-12-11 16:58

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0015_auto_20181124_2122"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="case",
            options={"ordering": ("-date",)},
        ),
    ]
