# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-22 19:11
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0003_relatedlaw"),
    ]

    operations = [
        migrations.AddField(
            model_name="law",
            name="created_date",
            field=models.DateTimeField(
                auto_now_add=True, default=django.utils.timezone.now
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="law",
            name="updated_date",
            field=models.DateTimeField(auto_now=True),
        ),
    ]
