# Generated by Django 2.0.4 on 2018-04-24 08:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("courts", "0009_auto_20180209_1604"),
    ]

    operations = [
        migrations.AddField(
            model_name="court",
            name="address_locality",
            field=models.CharField(
                blank=True, help_text="Locality (city name)", max_length=200, null=True
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="fax_number",
            field=models.CharField(
                blank=True, help_text="Fax number", max_length=200, null=True
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="homepage",
            field=models.URLField(
                blank=True, help_text="Official court homepage", null=True
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="postal_code",
            field=models.CharField(
                blank=True,
                help_text="Postal code (ZIP code)",
                max_length=200,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="street_address",
            field=models.CharField(
                blank=True,
                help_text="Street address with house number",
                max_length=200,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="court",
            name="telephone",
            field=models.CharField(
                blank=True, help_text="Telephone number", max_length=200, null=True
            ),
        ),
        migrations.AlterField(
            model_name="city",
            name="name",
            field=models.CharField(help_text="City name", max_length=100),
        ),
        migrations.AlterField(
            model_name="city",
            name="state",
            field=models.ForeignKey(
                help_text="State of city",
                on_delete=django.db.models.deletion.CASCADE,
                to="courts.State",
            ),
        ),
    ]
