# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-21 10:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="case",
            name="pdf_url",
            field=models.URLField(blank=True, null=True),
        ),
    ]
