# Generated by Django 2.1.2 on 2019-01-31 22:40

import re

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("annotations", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="annotationlabel",
            name="color",
            field=models.CharField(
                blank=True,
                max_length=18,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        re.compile("^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$"),
                        "Enter a valid color.",
                        "invalid",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="annotationlabel",
            name="slug",
            field=models.SlugField(
                blank=True,
                help_text="Identifier, e.g. this-awesome-annotation",
                max_length=100,
            ),
        ),
    ]
