# Generated by Django 2.1.1 on 2018-09-21 11:04

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0011_auto_20180917_1455"),
    ]

    operations = [
        migrations.AlterField(
            model_name="law",
            name="content",
            field=models.TextField(
                blank=True,
                help_text="Law content with HTML tags and reference markers (managed by CKEditor)",
            ),
        ),
    ]
