# Generated by Django 2.1.2 on 2019-02-18 12:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0018_add_db_indexes"),
        ("annotations", "0002_auto_20190131_2240"),
    ]

    operations = [
        migrations.CreateModel(
            name="CaseMarker",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("value_str", models.CharField(blank=True, max_length=250, null=True)),
                ("value_int", models.IntegerField(blank=True, null=True)),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Entry is created at this date time",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True, help_text="Date time of last change"
                    ),
                ),
                (
                    "start",
                    models.PositiveIntegerField(
                        db_index=True,
                        default=0,
                        help_text="Start position of marker (from 0)",
                    ),
                ),
                (
                    "end",
                    models.PositiveIntegerField(
                        db_index=True, default=0, help_text="End position of marker"
                    ),
                ),
                (
                    "belongs_to",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="cases.Case"
                    ),
                ),
                (
                    "label",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="annotations.AnnotationLabel",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
