# Generated by Django 2.1.1 on 2018-09-21 11:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cases", "0010_case_abstract"),
    ]

    operations = [
        migrations.AlterField(
            model_name="case",
            name="abstract",
            field=models.TextField(
                blank=True,
                help_text="Case abstract (Leitsatz) formatted in HTML",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="case",
            name="content",
            field=models.TextField(help_text="Case full-text formatted in Legal HTML"),
        ),
    ]
