# Generated by Django 2.1.2 on 2018-10-31 10:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("topics", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="topic",
            name="slug",
            field=models.SlugField(
                blank=True, help_text="Slug based on title", max_length=200, unique=True
            ),
        ),
    ]
