# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2018-01-06 11:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("laws", "0007_lawbook_latest"),
    ]

    operations = [
        migrations.AddField(
            model_name="law",
            name="content",
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name="law",
            name="title",
            field=models.CharField(default="", max_length=200),
        ),
    ]
