# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-21 13:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("references", "0002_auto_20171221_1318"),
    ]

    operations = [
        migrations.AlterField(
            model_name="casereference",
            name="to",
            field=models.CharField(max_length=250),
        ),
        migrations.AlterField(
            model_name="lawreference",
            name="to",
            field=models.CharField(max_length=250),
        ),
    ]
